@@ -25,7 +25,9 @@ import requests
 import validators
 from ruamel.yaml import YAML
 
-from .model import FetcherMetadata
+from .model import FetcherMetadata, PipelinesConfig
+
+__all__ = ["load_fetchers_yml", "load_pipelines_yml"]
 
 logger = daiquiri.getLogger(__name__)
 
@@ -43,9 +45,18 @@ def load_bytes(source: str) -> bytes:
     return Path(source).read_bytes()
 
 
-def load_fetchers_yml(fetchers_yml_ref: str):
-    logger.info("Loading fetcher metadata from %s...", fetchers_yml_ref)
-    fetchers_yml_text = load_bytes(fetchers_yml_ref)
-    fetchers_yml = yaml.load(fetchers_yml_text)
-    fetcher_metadata = FetcherMetadata.parse_obj(fetchers_yml)
-    return fetcher_metadata
+def load_fetchers_yml(fetchers_yml_ref: str) -> FetcherMetadata:
+    logger.debug("Loading fetcher metadata from %s...", fetchers_yml_ref)
+    fetchers_yml_data = load_yml_file(fetchers_yml_ref)
+    return FetcherMetadata.parse_obj(fetchers_yml_data)
+
+
+def load_pipelines_yml(pipelines_yml_ref: str) -> PipelinesConfig:
+    logger.debug("Loading pipelines config from %s...", pipelines_yml_ref)
+    pipelines_yml_data = load_yml_file(pipelines_yml_ref)
+    return PipelinesConfig.parse_obj(pipelines_yml_data)
+
+
+def load_yml_file(ref: str):
+    text = load_bytes(ref)
+    return yaml.load(text)
